@@ -1,4 +1,4 @@
-import RPIRateMyProfessors.py
+import RPIRateMyProfessors
 __all__ = ['RPIRateMyProfessors']
 
 
